IntoScanCursor

Trait IntoScanCursor 

pub trait IntoScanCursor<'a>: Sized {
    type Output: 'a + ScanCursor<'a>;

    // Required method
    fn into_scan_cursor(self) -> Self::Output;
}
Conversion into a ScanCursor.

This is a helper trait used to convert different values into a scannable cursor type. Implement this if you want your type to be usable as input to one of the scanning macros.

Required Associated Types

type Output: 'a + ScanCursor<'a>

The corresponding scannable cursor type.

Required Methods

fn into_scan_cursor(self) -> Self::Output

Convert this into a scannable cursor.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a> IntoScanCursor<'a> for &'a Cow<'a, str>

Source

impl<'a> IntoScanCursor<'a> for &'a String

Source

impl<'a> IntoScanCursor<'a> for &'a str

Implementors

Source

impl<'a, T> IntoScanCursor<'a> for T
where T: 'a + ScanCursor<'a>,