SliceWord

Trait SliceWord 

pub trait SliceWord: 'static {
    // Required method
    fn slice_word(s: &str) -> Option<usize>;
}
Defines an interface for slicing words out of input and literal text.

Required Methods

fn slice_word(s: &str) -> Option<usize>

If s starts with a word, how long is it?

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors