Trait scan_rules::input::SliceWord
[−]
[src]
pub trait SliceWord: 'static {
fn slice_word(s: &str) -> Option<usize>;
}Defines an interface for slicing words out of input and literal text.
Required Methods
fn slice_word(s: &str) -> Option<usize>
If s starts with a word, how long is it?
Implementors
impl SliceWord for Wordish